%define major 29
%define libname %mklibname %{name} %{major}
%define develname %mklibname -d %{name}

%define snapshot 0
%if %{?snapshot}
%define date 20170730
%define snaprel 1
%endif

Summary:	Command-line tools and library for transforming PDF files
Name:		qpdf
Version:	11.9.0
Release:	%mkrel 1%{?date:.%{date}.%{snaprel}}
# MIT: e.g. libqpdf/sha2.c
# upstream uses ASL 2.0 now, but he allowed other to distribute qpdf under
# old license (see README)
License: (Artistic 2.0 or ASL 2.0) and MIT
Group:		System/Printing
URL:		https://qpdf.sourceforge.net/
%if 0%{?date}
Source0:	%{name}-%{version}+%{date}.tar.xz
%else
Source0:	https://github.com/qpdf/qpdf/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1: https://github.com/qpdf/qpdf/releases/download/v%{version}/%{name}-%{version}-doc.zip
%endif

# make qpdf working under FIPS, downstream patch
Patch1:  qpdf-relax.patch

# uses cmake
BuildRequires: cmake

BuildRequires:	pkgconfig(zlib)
# for gnutls crypto
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(libjpeg)
# for fix-qdf and test suite
BuildRequires:	perl
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Digest::MD5)
BuildRequires:	perl(Digest::SHA)
BuildRequires:	perl(File::Basename)
BuildRequires:  perl(File::Compare)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IO::Select)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(strict)
# perl(Term::ANSIColor) - not needed for tests
# perl(Term::ReadKey) - not needed for tests

%description
QPDF is a command-line program that does structural, content-preserving
transformations on PDF files. It could have been called something
like pdf-to-pdf. It includes support for merging and splitting PDFs
and to manipulate the list of pages in a PDF file. It is not a PDF viewer
or a program capable of converting PDF into other formats.

%package -n	%{libname}
Summary:	QPDF library for transforming PDF files
Group:		System/Libraries

%description -n	%{libname}
QPDF is a C++ library that inspect and manipulate the structure of PDF files.
It can encrypt and linearize files, expose the internals of a PDF file,
and do many other operations useful to PDF developers.

%package -n	%{develname}
Summary:	Development files for QPDF library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}

%description -n	%{develname}
Header files and libraries necessary
for developing programs using the QPDF library.

%package	doc
Summary:	QPDF Manual
Group:		Documentation
BuildArch:	noarch

%description	doc
QPDF Manual

%prep
%if 0%{?date}
%autosetup -p1 -n %{name}-%{version}+%{date}
%else
%autosetup -p1
%endif

# unpack zip file with manual
unzip %{SOURCE1}

%build
%cmake -DBUILD_STATIC_LIBS=0 -DREQUIRE_CRYPTO_GNUTLS=1 -DUSE_IMPLICIT_CRYPTO=0 -DSHOW_FAILED_TEST_OUTPUT=1 -DINSTALL_CMAKE_PACKAGE=0

%cmake_build

%install
%cmake_install

install -m 0644 %{name}-%{version}-doc/%{name}-manual.pdf %{buildroot}/%{_pkgdocdir}/%{name}-manual.pdf

# install bash/zsh completions
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
install -m 0644 completions/bash/qpdf %{buildroot}%{_datadir}/bash-completion/completions/qpdf
install -m 0644 completions/zsh/_qpdf %{buildroot}%{_datadir}/zsh/site-functions/_qpdf

%check
%ctest

%files
%{_bindir}/fix-qdf
%{_bindir}/qpdf
%{_bindir}/zlib-flate
%{_mandir}/man1/*
%{_datadir}/bash-completion/completions/qpdf
%{_datadir}/zsh/site-functions/_qpdf

%files -n %{libname}
%doc README.md TODO.md ChangeLog
%license Artistic-2.0 LICENSE.txt NOTICE.md
%{_libdir}/libqpdf*.so.%{major}
%{_libdir}/libqpdf*.so.%{major}.*

%files -n %{develname}
%doc examples/*.cc examples/*.c
%{_includedir}/qpdf/
%{_libdir}/libqpdf.so
%{_libdir}/pkgconfig/libqpdf.pc

%files doc
%{_pkgdocdir}


%changelog
* Tue Mar 19 2024 ns80 <ns80> 11.9.0-1.mga9
+ Revision: 2050866
- new version 11.9.0 for CVE-2024-24246 (mga#32958)

* Tue Mar 14 2023 luigiwalser <luigiwalser> 11.3.0-1.mga9
+ Revision: 1948868
- 11.3.0
- update qpdf-relax patch from fedora
+ danf <danf>
- Fix source URLs

* Fri Oct 14 2022 tv <tv> 11.1.1-1.mga9
+ Revision: 1896869
- qpdf-11.1.1
- qpdf doesn't depend on pcre since 7.0b1

* Mon Jul 18 2022 tv <tv> 10.6.3-2.mga9
+ Revision: 1869281
- FIPS breaks pdftopdf and bannertopdf (rhbz#2107240)

* Wed Mar 23 2022 tv <tv> 10.6.3-1.mga9
+ Revision: 1822770
- qpdf-10.6.3 is available

* Thu Feb 17 2022 tv <tv> 10.6.2-1.mga9
+ Revision: 1779453
- qpdf-10.6.2 is available

* Wed Feb 16 2022 tv <tv> 10.6.1-1.mga9
+ Revision: 1777876
- qpdf-10.6.1 is available

* Fri Feb 11 2022 tv <tv> 10.6.0-1.mga9
+ Revision: 1773000
- qpdf-10.6.0 is available

* Fri Jan 07 2022 tv <tv> 10.5.0-2.mga9
+ Revision: 1767253
- Package pdf doc instead of useless css style sheet

* Fri Jan 07 2022 tv <tv> 10.5.0-1.mga9
+ Revision: 1767188
- qpdf-10.5.0 is available

* Tue Dec 07 2021 tv <tv> 10.4.0-1.mga9
+ Revision: 1761039
- qpdf-10.4.0 is available

* Wed May 26 2021 tv <tv> 10.3.2-1.mga9
+ Revision: 1728399
- 10.3.2

* Fri Mar 12 2021 tv <tv> 10.3.1-1.mga9
+ Revision: 1701671
- 10.3.1

* Sun Feb 28 2021 tv <tv> 10.2.0-1.mga9
+ Revision: 1693185
- qpdf-10.2.0

* Tue Jan 12 2021 tv <tv> 10.1.0-1.mga8
+ Revision: 1671324
- qpdf-10.1.0

* Mon Nov 23 2020 tv <tv> 10.0.4-1.mga8
+ Revision: 1648658
- 10.0.4

* Tue Nov 03 2020 tv <tv> 10.0.3-1.mga8
+ Revision: 1642081
- 10.0.3

* Tue Apr 14 2020 tv <tv> 10.0.1-1.mga8
+ Revision: 1567287
- 10.0.1 (major is now 28)
- Add all perl dependencies for tests

* Mon Jan 27 2020 tv <tv> 9.1.1-1.mga8
+ Revision: 1484044
- 9.1.1
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Nov 23 2019 tv <tv> 9.1.0-1.mga8
+ Revision: 1462264
- drop merged patch
- 9.1.0
- major is now 26

* Mon May 13 2019 luigiwalser <luigiwalser> 8.4.1-1.mga8
+ Revision: 1397529
- 8.4.1

* Sat Feb 02 2019 luigiwalser <luigiwalser> 8.4.0-1.mga7
+ Revision: 1362674
- 8.4.0

* Mon Jan 14 2019 luigiwalser <luigiwalser> 8.3.0-1.mga7
+ Revision: 1356766
- 8.3.0

* Wed Oct 03 2018 tv <tv> 8.2.1-1.mga7
+ Revision: 1316242
- 8.2.1
- correcting license
- more tests fail because aarch64 zlib optimization - add patch for it
- erase failing tests for aarch64 because of zlib optimization
- use %%license
- remove old stuff

* Fri May 04 2018 luigiwalser <luigiwalser> 7.1.1-3.mga7
+ Revision: 1226067
- add patch from fedora to fix CVE-2018-9918

* Mon Feb 19 2018 kekepower <kekepower> 7.1.1-2.mga7
+ Revision: 1202923
- Add BR for libjpeg
- Update to version 7.1.1

* Sun Jul 30 2017 akien <akien> 6.0.0-2.20170730.1.mga7
+ Revision: 1132858
- Git snapshot with security fixes (including CVE-2017-920[89] and CVE-2017-9210, mga#20915)

* Fri Feb 12 2016 umeabot <umeabot> 6.0.0-2.mga6
+ Revision: 958702
- Mageia 6 Mass Rebuild

* Mon Jan 18 2016 luigiwalser <luigiwalser> 6.0.0-1.mga6
+ Revision: 925483
- 6.0.0
- library major is now 17

* Sat Aug 29 2015 tv <tv> 5.1.3-3.mga6
+ Revision: 870774
- rebuild with gcc5

* Sat Aug 29 2015 cjw <cjw> 5.1.3-2.mga6
+ Revision: 870770
- rebuild with gcc 5

* Tue Jun 23 2015 tv <tv> 5.1.3-1.mga6
+ Revision: 840264
- new release

* Wed Oct 15 2014 umeabot <umeabot> 5.1.2-3.mga5
+ Revision: 741562
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.1.2-2.mga5
+ Revision: 688503
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 tv <tv> 5.1.2-1.mga5
+ Revision: 664113
- new release

* Mon Mar 24 2014 tv <tv> 5.1.1-4.mga5
+ Revision: 608192
- drop temporary cauldron upgrade fix

* Thu Mar 13 2014 tv <tv> 5.1.1-3.mga5
+ Revision: 603256
- temporary upgrade fix
- fix broken libification

* Thu Mar 13 2014 neoclust <neoclust> 5.1.1-2.mga5
+ Revision: 603251
- Fix major name

* Thu Mar 13 2014 dams <dams> 5.1.1-1.mga5
+ Revision: 603229
- new version 5.1.1

* Sat Oct 19 2013 umeabot <umeabot> 4.0.1-2.mga4
+ Revision: 524051
- Mageia 4 Mass Rebuild

* Wed May 29 2013 tv <tv> 4.0.1-1.mga4
+ Revision: 429875
- imported package qpdf


* Tue May 28 2013 Thierry Vignaud <tv@mageia.org> 4.0.1-1.mga4
- imported from FC
